@@ -96,7 +96,7 @@ class EventMuxer(AutoRepr):
         for waiter in self.waiters:
             if await waiter.check(ev):
                 waiter.future.set_result(ev)
-                done.add(done)
+                done.add(waiter)
         self.waiters -= done
 
         coros = [func(ev) for func in self.funcs]
